@@ -7,18 +7,18 @@
   SPDX-FileCopyrightText: 2001 Waldo Bastian <bastian@kde.org>
   SPDX-FileCopyrightText: 2004 Daniel Molkentin <danimo@klaralvdalens-datakonsult.se>
   SPDX-FileCopyrightText: 2004 Karl-Heinz Zimmer <khz@klaralvdalens-datakonsult.se>
-  SPDX-FileCopyrightText: 2017-2024 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2017-2025 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "addresseelineedit.h"
-using namespace Qt::Literals::StringLiterals;
 
 #include "addresseelineedit_p.h"
 #include "addresseelineeditmanager.h"
 #include "addresseelineeditutil.h"
 #include "addressline/recentaddress/recentaddresses.h"
+#include <KLDAPCore/LdapActivitiesAbstract>
 #include <KLDAPCore/LdapClientSearch>
 
 #include <KContacts/VCardConverter>
@@ -58,6 +58,7 @@ using namespace Qt::Literals::StringLiterals;
 #include <QObject>
 
 using namespace PimCommon;
+using namespace Qt::Literals::StringLiterals;
 
 inline bool itemIsHeader(const QListWidgetItem *item)
 {
@@ -91,6 +92,11 @@ AddresseeLineEdit::~AddresseeLineEdit()
     delete d;
 }
 
+void AddresseeLineEdit::setLdapActivitiesAbstract(KLDAPCore::LdapActivitiesAbstract *ldapActivities)
+{
+    d->setLdapActivitiesAbstract(ldapActivities);
+}
+
 void AddresseeLineEdit::setFont(const QFont &font)
 {
     KLineEdit::setFont(font);
@@ -117,7 +123,7 @@ void AddresseeLineEdit::setExpandIntern(bool expand)
 
 void AddresseeLineEdit::setEnableBalooSearch(bool enable)
 {
-    d->setEnableBalooSearch(enable);
+    d->setEnableAkonadiSearch(enable);
 }
 
 bool AddresseeLineEdit::enableBalooSearch() const
@@ -216,7 +222,7 @@ void AddresseeLineEdit::insert(const QString &t)
 
     if (hasSelectedText()) {
         // Cut away the selection.
-        int start_sel = selectionStart();
+        const int start_sel = selectionStart();
         pos = start_sel;
         contents = contents.left(start_sel) + contents.mid(start_sel + selectedText().length());
     }
@@ -545,7 +551,7 @@ void AddresseeLineEdit::addContact(const KContacts::Addressee &addr, int weight,
 void AddresseeLineEdit::contextMenuEvent(QContextMenuEvent *event)
 {
     QMenu *menu = createStandardContextMenu();
-    if (menu) { // can be 0 on platforms with only a touch interface
+    if (menu) { // can be nullptr on platforms with only a touch interface
         menu->exec(event->globalPos());
         delete menu;
     }
@@ -598,8 +604,9 @@ void AddresseeLineEdit::configureCompletion()
     dlg->setRecentAddresses(PimCommon::RecentAddresses::self(recentAddressConfig())->addresses());
     dlg->setLdapClientSearch(ldapSearch());
     dlg->setEmailBlackList(PimCommon::AddresseeLineEditManager::self()->balooBlackList());
+    dlg->setLdapActivitiesAbstract(d->ldapActivitiesAbstract());
     dlg->load();
-    if (dlg->exec() && dlg) {
+    if (dlg->exec()) {
         if (dlg->recentAddressWasChanged()) {
             PimCommon::RecentAddresses::self(recentAddressConfig())->clear();
             dlg->storeAddresses(recentAddressConfig());
